Basific class
Singleton class to manage Basific configuration
Constructors
- Basific()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- config → BasificConfig
-
Get current configuration
no setter
- currentUser → BasificUser?
-
Quick access to current authenticated user
no setter
- isAuthenticated → bool
-
Quick access to authentication status
no setter
- isInitialized → bool
-
Check if Basific is initialized
no setter
- supabase → SupabaseClient
-
Get Supabase client
no setter
Static Methods
-
initialize(
BasificConfig config) → Future< void> - Initialize Basific with configuration
-
login(
String email, String password) → Future< BasificAuthResult> - Quick login method
-
loginWithUsernameOrEmail(
String usernameOrEmail, String password) → Future< BasificAuthResult> - Quick login method with username or email
-
logout(
) → Future< BasificAuthResult> - Quick logout method
-
register(
{required String email, required String password, String? displayName, String? fullName, String? role}) → Future< BasificAuthResult> - Quick register method
-
resetPassword(
String email) → Future< BasificAuthResult> - Quick password reset method